AddDist_legacy This add Jaccard, Dice, Jaccard3W distance and stored in DistObjects
Source:R/buid_tree.R
AddDist_legacy-mitoTracing-method.RdAddDist_legacy This add Jaccard, Dice, Jaccard3W distance and stored in DistObjects
Usage
# S4 method for mitoTracing
AddDist_legacy(
object,
jaccard = T,
dice = T,
jaccard3w = T,
w_jaccard = T,
w_cosine = T,
weightDF = NULL,
NN = 1,
LSIdist = T,
dim = 2:50
)Arguments
- object
mitoTracin class
- jaccard
default=T
- dice
default=T
- jaccard3w
default=T
- w_jaccard
default=T
- w_cosine
default=T
- NN
To replace NA, which means a variant shown in the object is not shown in the weight vector, with a number, default is 1 for jaccard system.
- LSIdist
default=T
- dim
the dimensions to use to calculate LSI distance default is 2:50
- weight
A two column dataframe, "Variant"(The variant name should match cell-variant matrix column, e.g, Variants310TC), "weight" (numeric)