Function to add hematopoietic signatures from Griffin_Signatures
Source:R/utils.R
AddHemSignature.RdThis function allows you to input a seurat object, add the signatures and return an seurat object
R/utils.R
AddHemSignature.RdThis function allows you to input a seurat object, add the signatures and return an seurat object