Add_Tree Optional, if a phylogentic tree object phylo is already available, can be directly added to the redeemR
Source:R/buid_tree.R
AddTree.RdAdd_Tree Optional, if a phylogentic tree object phylo is already available, can be directly added to the redeemR