Skip to contents

Add_Tree Optional, if a phylogentic tree object phylo is already available, can be directly added to the redeemR class in slot TREE

Usage

# S4 method for redeemR
AddTree(object, phylo, record = "")

Arguments

object

redeemR class

phylo

phyogenetic tree object

Value

redeemR class