Skip to contents

Add_DepthMatrix Optional, add a matrix with same dimension with the Cts.Mtx and Cts.Mtx.bi, which display the depths

Usage

# S4 method for redeemR
Add_DepthMatrix(object, QualifiedTotalCts = "")

Arguments

object

redeemR class

QualifiedTotalCts

a big source data, usually at XXX/mitoV/final, If needed, edit V1, the cell name, which may have additional postfix due to combine

Value

redeemR class