Skip to contents

Old Function to read in redeemV outputs It process the data same way as redeemR.read but simultanously reading in all threadhold as a list This function allows you to read raw data from XX/final folder, the output from redeemV

Usage

CW_mgatk.read(path, Processed = F)

Arguments

path

The XX/final folder, the output from mitoV

Processed

Boolean variable (Default F), if true directly readRDS("VariantsGTSummary.RDS") or, generate and saveout "VariantsGTSummary.RDS"

Value

this returns depth which is a list of 4 df (Total/LS/S/VS), each is a genotype summary

Examples

if (FALSE) {
WD <- "/path/to/redeemV/final"
DN1CD34_1.VariantsGTSummary <- CW_mgatk.read(WD, Processed = TRUE)
}