Define a function to perform Find marker for top vs bottom clones This function was developed based on DN4T2.basics.ipynb
Source:R/buid_tree.R
Clone_FinderMarker.RdDefine a function to perform Find marker for top vs bottom clones This function was developed based on DN4T2.basics.ipynb
Usage
Clone_FinderMarker(
topClones,
bottomClones,
HSC_Multiome_wrapper = Donor04_HSC_Multiome_wrapper,
HSC_redeemR,
assay = "SCT",
test = "wilcox"
)Arguments
- topClones
a vector of clone ID eg. c("1","3","7"),this must be in HSC_redeemR@CellMeta$Clone_merge
- bottomClones
a vector of clone ID eg. c("2","5"), this must be in HSC_redeemR@CellMeta$Clone_merge
- HSC_redeemR
redeemR object for HSC
- test
the statistic method to use for DE, a wrapper function from Seurat FindAllMarkers
- ob
Seurat object (Multiomics), the postfix needs to be compatible with HSC_redeemR, the cells will be matched by cell names