Function to compute the reject rate(The filtering rate in concensus variant calling)
Source:R/variant_summary.R
ComputeRejectRate.RdThis function allows you to computae the filtering rate for each single cell
R/variant_summary.R
ComputeRejectRate.RdThis function allows you to computae the filtering rate for each single cell