Skip to contents

This function allows you to computae the filtering rate for each single cell

Usage

ComputeRejectRate_legacy(WD)

Arguments

WD

The path to the work space usually XXX/mitoV/final

Value

a dataframe that store the percentage of variant in a given threahold again total

Examples

if (FALSE) {
DN9_BMMC_RejectRate <- ComputeRejectRate_legacy("/path/to/redeemV/final/")
}