CountOverlap_Adj function to count the connectedness (adjacency matrix), or the number of cells sharing more than n variants with the given cell
Source:R/utils.R
CountOverlap_Adj.RdCountOverlap_Adj function to count the connectedness (adjacency matrix), or the number of cells sharing more than n variants with the given cell