This function is to prepare the data format that is used to differentially expression calling. It include the raw matrix; data.info and size effect
This function is to prepare the data format that is used to differentially expression calling. It include the raw matrix; data.info and size effect