Skip to contents

This is the main function for calculating differentially expressed genes

Usage

DoDE(tri.dummy, cpcol, onlyoneSample = F, cpus = 16)

Arguments

tri.dummy

this is generated from DE.gettripple

cpcol

the column in tri.dummy$info, the contents of which are used for iteratively compare with one another

onlyoneSample

If true, regress out batch effect. Notice, there should be a "Sample" column in in tri.dummy$info that indicate sample or donor or batch

cpus

a number of cpus being used for calculation, default is 16

Value

return a list that includes all DE result iteratively

Examples

if (FALSE) {
ROCKvsnorock.endo.de <- DoDE(ROCKvsnorock.endo.tri.dummy, "name", onlyoneSample = TRUE, cpus = 16)
}