FromDist2Graph From distance object or matrix to graph, default is to return igraph object This function was developed based on
Source:R/buid_tree.R
FromDist2Graph.RdFromDist2Graph From distance object or matrix to graph, default is to return igraph object This function was developed based on