This function is to do GSEA enrichment analysis, to be updated
Usage
Fun.enrich_withFC.pvalue(
markergenesList,
All.genes = all.genes.refer,
db = msig.db,
qcutoff = 0.05,
top = NULL
)Arguments
- markergenesList
is a list containing several elements each of which is a vector of gene names
- All.genes
the background genes data(all.genes.refer)
- db
=msig.db the term database to use, default is the msig.db; data(msig.db)
- qcutoff=0.05
the term to show with q value lower than 0.05
- top=NULL
pass a number to only show top # terms