This function allows you to summarize the meta data for each genotyped variant
Arguments
- RawGenotypes
Well-named "RawGenotypes.Sensitive.StrandBalance" file in function redeemR.read or CW_mgatk.read
- filterN
Boolean variable, if true filter out the variant with "N"
Details
Usually used inside redeemR.read() or CW_mgatk.read().