This function identify specific mutations for each clone based on Fisher Exact Test Of note, the ReDeeM object need to have Clone_merge in CellMeta (After running Add_tree_cut)
This function identify specific mutations for each clone based on Fisher Exact Test Of note, the ReDeeM object need to have Clone_merge in CellMeta (After running Add_tree_cut)