Define a function make the Allnodes(Node|Parent|Freq|CladeSize), where Freq is the number of variants assigned to the node(as ending point) from redeemR object,
Source:R/buid_tree.R
MakeAllNodes.RdDefine a function make the Allnodes(Node|Parent|Freq|CladeSize), where Freq is the number of variants assigned to the node(as ending point) from redeemR object,