Define a function to make nn list, which can be further used to make adjacency matrix This scan row by row, looking for k.param nearest neighbours
Source:R/buid_tree.R
MakeNN.RdDefine a function to make nn list, which can be further used to make adjacency matrix This scan row by row, looking for k.param nearest neighbours