Define a function to make a list, each contains the cell names for a node
Source:R/buid_tree.R
Make_Cells4Nodes.RdDefine a function to make a list, each contains the cell names for a node
Usage
Make_Cells4Nodes(
tr = DN4_SLCT_HSC_w_jaccard.njtree@phylo,
min.node.size = 10,
max.node.fra = 0.33
)Arguments
- tr
phylo object (ape)
- min.node.size
default is 10, only the nodes with more than 10 tips are included ( # Minimum # tips in the node to be included)
- max.node.fra
default is 0.33, only consider the nodes with less than max.node.fra*total cell number (# The up limit of the node size(Fraction of all tips) to be considered)