Skip to contents

This function creates a lookup table showing how many cells have non-zero coverage at each position for each threshold

Usage

PosCoverageCellCount(path, CellSubset = NA)

Arguments

path

The XX/final folder, the output from mitoV

CellSubset

A vector of ATAC cell names for subsetting, default is NA

Value

A dataframe with Position and counts of cells with non-zero coverage for each threshold (Total, LS, S, VS)

Examples

if (FALSE) {
WD <- "/path/to/redeemV/final"
pos_coverage <- PosCoverageCellCount(WD)
}