Define a function to perform single-cell based hard porogeny assignment This function was developed based on DN4T2.basics.ipynb
Source:R/buid_tree.R
ProgenyMapping.RdDefine a function to perform single-cell based hard porogeny assignment This function was developed based on DN4T2.basics.ipynb