ProgenyMapping_np Define a function to compute network propagation based probability FromDist2Graph is needed to convert fistance matrix into MNN graph
Source:R/buid_tree.R
ProgenyMapping_np.RdProgenyMapping_np Define a function to compute network propagation based probability FromDist2Graph is needed to convert fistance matrix into MNN graph
Usage
ProgenyMapping_np(
HSC_redeemR = DN4_stemcell_redeemR.seed.verysensitive,
Full_redeemR = DN4_BMMC_HSPC_HSC_redeemR.verysensitive,
CloneCol = "Clone_merge",
k = 30,
gm = 0.5,
useLSI = F,
useSCAVENGE_LSI = F,
subsample = F,
ProbCut = 0.7,
Celltype = "Rig.CellType"
)Arguments
- HSC_redeemR
The HSC_redeemR is the redeemR object for defined HSC, have already gone through Add_DepthMatrix--Add_AssignVariant--Add_tree_cut, otherwise, need othereise, need a column in CellMeta that indicates the clone ID
- Full_redeemR
The FULL_redeemR is the redeemR object for the full BMMC_HSPC_HSC
- CloneCol
"Clone_merge"
- k
the k.param used for MNN graph
- gm
gamma default is 0.05 which mean 95% information is passing out
- ProbCut
The cutoff of the maximum probability for a given progeny cell(If the maximum probability is lower than ProbCut, it will be filtered)
- Celltype
The column to be used in aggregate into lineages