This function allows you to input a seurat object(multiome), redo clustering harmony by a certain column in meta data. Usually this is after subset
Usage
Reclustering_hm(
ob = DN4_RigHSC_T1T2_Multiome_wrapper_filtered.anno,
HarmonyBy = "TimePoint"
)
Arguments
- ob
a seurat object
- HarmonyBy
The columne name in meta that will be used for Harmony