SeuratLSIClustering This will use the mito variants for Seurat clustering (LSI based)
Source:R/buid_tree.R
SeuratLSIClustering-redeemR-method.RdSeuratLSIClustering This will use the mito variants for Seurat clustering (LSI based)
Usage
# S4 method for redeemR
SeuratLSIClustering(
object,
binary = T,
res = 0.6,
lsidim = 2:50,
rmvariants = c("Variants310TC", "Variants3109TC", "Variants5764CT")
)