Skip to contents

This function allows you to input the metadata with row name as cell barcode

This function allows you to input the metadata with row name as cell barcode

Usage

Translate_RNA2ATAC(
  meta = bmmc.filtered@meta.data,
  PostFix = T,
  bclength = 16,
  from = c(1, 2, 3),
  to = c(1, 2, 3)
)

Translate_RNA2ATAC(
  meta = bmmc.filtered@meta.data,
  PostFix = T,
  bclength = 16,
  from = c(1, 2, 3),
  to = c(1, 2, 3)
)

Arguments

meta

a dataframe with the row names as the RNA cell barcode usually with the post -1

bclength

The cell barcode length, default is 16

from

A vector of the postfix, usually is c(1,2,3,...), it depends on how many samples are aggregated in Cellranger RNA part

to

A vector of the postfix, those cooresponds to the postfix added in redeemR, in general, if it matches, then simply c(1,2,3,...), but in case not match, here provides a way to transform into scredeemR order

Value

meta a dataframe

meta a dataframe

Examples

if (FALSE) {
Translate_RNA2ATAC(meta)
}
if (FALSE) {
Translate_RNA2ATAC(meta)
}