This function allows you to input the ATAC name to translate to RNA name
Arguments
- name
RNA name, as the RNA cell barcode usually with the post -1
- bclength
The cell barcode length, default is 16
- from
A vector of the postfix, usually is c(1,2,3,...), it depends on how many samples are aggregated in Cellranger RNA part
- to
A vector of the postfix, those cooresponds to the postfix added in redeemR, in general, if it matches, then simply c(1,2,3,...), but in case not match, here provides a way to transform into redeemR order