This function allows you to filter variants,deprecated, use Vfilter_v4 instead
Usage
Vfilter_v3(
InputSummary,
depth,
Rmvhomo = F,
Min_Cells = 2,
Max_Count_perCell = 2,
QualifyCellCut = 10
)Arguments
- InputSummary
The GTSummary file read in by function CW_mgatk.read
- depth
The .depth file by function DepthSummary
- Rmvhomo
Boolean (Default F) If true, remove the homozygous variants
- Min_Cells
Default 2, A qualified variant needs the minimum number of cells that have this variant
- Max_Count_perCell
Default 2, A qualified variant needs to show at least 2 counts in one cell
- QualifyCellCut
Default 10, Minimum depth for a qualified cell