Convinient function that takes raw fragment, and out put fragment with frequency Produce KS test results, input is the redeem object from redeemR object,
Source:R/variant_summary.R
add_freq_raw.RdConvinient function that takes raw fragment, and out put fragment with frequency Produce KS test results, input is the redeem object from redeemR object,