Skip to contents

Flags variants whose genomic position falls within known problematic regions of the mitochondrial genome (blacklist regions).

Usage

annotate_variants_blacklist(variant_annotation)

Arguments

variant_annotation

A data.frame or tibble containing at least a column named Variants, where each entry is of the form "<pos>_<ref>_<alt>".

Value

The input variant_annotation with an added column:

blacklist_region

Character; "blacklist_region" if the variant position is in one of the predefined blacklist intervals, otherwise "".

Details

The blacklist intervals correspond to regions in the revised Cambridge Reference Sequence (rCRS) prone to misalignment:

  1. Misalignment due to ACCCCCC T C C C C C C (rCRS 302–315)

  2. Misalignment due to G C A C A C A C A C A C C (rCRS 513–525)

  3. Misalignment due to 3107N ambiguity in rCRS (rCRS 3105–3109)

  4. Misalignment due to ACCCCC homopolymer (rCRS 16182–16187)