Skip to contents

Flags variants that fall into the hypermutable category based on cell-level mutation frequencies.

Usage

annotate_variants_hypermutable(variant_annotation)

Arguments

variant_annotation

A data.frame or tibble containing at least a column named Variants whose entries are of the form “\ifhtml\ifhtml\ifhtml”.

Value

The same variant_annotation, with an added column:

hyper_label

Character; "hyper" if the variant is identified as hypermutable, otherwise "".

Details

This function loads the CellPCT.update dataset and retrieves the set of hypermutable variants via get_hype_v2(cut = 0.005). Those variant IDs are converted into the standard “” strings by convert_variant(), and any matches in the input table are labeled.