Skip to contents

Keeps only rows in @GTsummary.filtered where the cell is in cells_to_keep, enforces a minimum number of rows per variant, updates @V.fitered, and rebuilds matrices and depth matrix.

Usage

filter_redeemR_by_cells(
  redeemR_obj,
  cells_to_keep,
  min_cells_per_variant = 2,
  QualifiedTotalCts = NULL,
  filter_name = NULL,
  update_depth_matrix = TRUE
)

Arguments

redeemR_obj

A redeemR object.

cells_to_keep

Character vector of cell names to retain.

min_cells_per_variant

Integer; minimum rows per variant (default 2). This is needed because after filterout some cells, some mutation may only show in 1 cell

QualifiedTotalCts

Optional "QualifiedTotalCts" for depth rebuilding.

filter_name

Optional label for matrix-dimension printing.

Value

The updated redeemR object.