Skip to contents

Summarizes a variant-by-cell count matrix to produce per-variant metrics.

Usage

make_V.fitered_from_mtx(mtx)

Arguments

mtx

Numeric matrix with variants as columns and cells as rows.

Value

A data.frame with one row per variant, including the metrics above and a column Variants with variant identifiers (column names of mtx).

Details

Calculates for each variant (column of mtx):

  • cellNNumber of cells with count > 0.

  • max_countMaximum count observed across cells.

  • mean_countMean of non-zero counts.

  • ct1_cellNNumber of cells with count == 1.

  • ct2_cellNNumber of cells with count == 2.

  • ct3plus_cellNNumber of cells with count > 2.

  • pct_ct2plusFraction of cells with count >= 2.

  • cellNPCTFraction of cells with count > 0 relative to total cells.