Skip to contents

This function allows you to plot the mito mutation metrics For each category(stringency), p1: Variant allele frequency(VAF); p2: Heteroplasmy histogram p3: CellN(Number of caells that carry the variants) VS maxcts( The number of variant counts in the highest cell) p4: Histogram to show the distribution of the number of variant per cell

Usage

plot_variant(ob, p4xlim = 50, QualifyCellCut = 10)

Arguments

ob

The redeemR object

p4xlim

the p4 xlim(number of variant per cell), default is 50

QualifyCellCut

median coverage for qualified cells, default is 10

Value

A list containing both the combined patchwork plot and individual plots