This is a function borrowed from https://github.com/NickWilliamsSanger/treemut/blob/main/R/treemut.R#L68 Input phylo object, return a "profile matrix"--Edge(or denoted as the ending node) vs cell. a 0, 1 character string that indicate what cells in a given node
Source:R/buid_tree.R
reconstruct_genotype_summary.RdThis is a function borrowed from https://github.com/NickWilliamsSanger/treemut/blob/main/R/treemut.R#L68 Input phylo object, return a "profile matrix"--Edge(or denoted as the ending node) vs cell. a 0, 1 character string that indicate what cells in a given node