Returns a pair of integers for the number of rows and columns of a matrix-like object. If the input is NULL, returns NA for both values.
Returns a pair of integers for the number of rows and columns of a matrix-like object. If the input is NULL, returns NA for both values.