Add_Tree Optional, if a phylogentic tree object phylo is already available, can be directly added to the redeemR class in slot TREE
Source:R/buid_tree.R
AddTree-redeemR-method.RdAdd_Tree Optional, if a phylogentic tree object phylo is already available, can be directly added to the redeemR class in slot TREE
Usage
# S4 method for redeemR
AddTree(object, phylo, record = "")