Add_DepthMatrix Optional, add a matrix with same dimension with the Cts.Mtx and Cts.Mtx.bi, which display the depths
Source:R/buid_tree.R
Add_DepthMatrix-redeemR-method.RdAdd_DepthMatrix Optional, add a matrix with same dimension with the Cts.Mtx and Cts.Mtx.bi, which display the depths
Usage
# S4 method for redeemR
Add_DepthMatrix(object, QualifiedTotalCts = "")