Old Function to read in redeemV outputs It process the data same way as redeemR.read but simultanously reading in all threadhold as a list This function allows you to read raw data from XX/final folder, the output from redeemV
Source:R/variant_summary.R
CW_mgatk.read.RdOld Function to read in redeemV outputs It process the data same way as redeemR.read but simultanously reading in all threadhold as a list This function allows you to read raw data from XX/final folder, the output from redeemV