This is the main function for calculating differentially expressed genes
Arguments
- tri.dummy
this is generated from DE.gettripple
- cpcol
the column in tri.dummy$info, the contents of which are used for iteratively compare with one another
- onlyoneSample
If true, regress out batch effect. Notice, there should be a "Sample" column in in tri.dummy$info that indicate sample or donor or batch
- cpus
a number of cpus being used for calculation, default is 16