This function allows you to input a list of sparse matrix and merge by rownames, return a new sparse matrix
Arguments
- mtx.list
A list of sparse matrix to be merged
- postfix
a vector of postfix (Usually are numbers that added at the end of cell names). Better be consistent with a merged redeemR object orders
Examples
if (FALSE) {
Donor4_HSC_HPC_BMMC.Mtx <- MergeMtx(list(mtx1, mtx2, mtx3), c(3, 2, 1))
Donor4_HSC_HPC_BMMC.RNA.seurat <- GEM_Wrapper(Donor4_HSC_HPC_BMMC.Mtx)
}