This function allows you to perform standard sc-multiome clustering
Usage
Multi_Wrapper(
path =
"/lab/solexa_weissman/cweng/Projects/MitoTracing_Velocity/SecondaryAnalysis/Donor01_CD34_1_Multiomekit/CellRanger/Donor01_CD34_1/outs",
atacmin = 1000,
umimin = 1000,
CellID = NULL
)Arguments
- path
this should be the path to the cell-ranger results XX/outs
- atacmin
minimum atac fragment for each cell, default is 1000
- umimin
minimum rna umi for each cell, default is 1000
- cellID
to be used for input(useful for re-clustering), default is NULL which will use the info from path/per_barcode_metrics.csv