Annotate variants with mitochondrial homopolymer context
Source:R/variant_annotation.R
annotate_variants_homopolymer.RdFlags each variant by the homopolymer region in which its position falls, based on predefined mitochondrial homopolymer intervals.
Arguments
- variant_annotation
A data.frame or tibble containing at least a column named
Variants, where each entry is of the form"<pos>_<ref>_<alt>".