Flags variants that fall into the hypermutable category based on cell-level mutation frequencies.
Value
The same variant_annotation, with an added column:
hyper_labelCharacter;
"hyper"if the variant is identified as hypermutable, otherwise"".
Details
This function loads the CellPCT.update dataset and retrieves the set
of hypermutable variants via get_hype_v2(cut = 0.005). Those variant
IDs are converted into the standard “convert_variant(), and any matches in the input table are labeled.