Annotate variant table with population frequency and haplogroup statistics
Source:R/variant_annotation.R
annotate_variants_population_stats.RdAdds mitochondrial variant information from mitomap_freq and haplogroup
marker counts from haplogroup_markers to a variant annotation table. Existing
columns that would collide with the annotation fields are removed before the
joins are applied.