This function allows you to plot the mito mutation metrics For each category(stringency), p1: Variant allele frequency(VAF); p2: Heteroplasmy histogram p3: CellN(Number of caells that carry the variants) VS maxcts( The number of variant counts in the highest cell) p4: Histogram to show the distribution of the number of variant per cell