Function to read in multiple runs of redeemV outputs with edge trimming, default is trimming 5bp
Source:R/variant_summary.R
redeemR.read.multiple.trim.RdThis function allows you to read raw data from multiple XX/final folder, the output from redeemV It process the data same way as CW_mgatk.read but need to specify one threadhold(thr)
Arguments
- paths
a vector of multiple path strings The XX/final folder, the output from mitoV
- names
The names for the multiple input, same order with folder
- suffix
The suffix for the multiple input, which is added at the end of cell name, separated by "."
- edge_trim
how many bp to be trimmed, default is 5,